@@ -9,7 +9,8 @@ test_obj <- prep_sig(df_sig = data.frame(type = c("Type_1", "Type_1", "Type_2",
                                          fa_2 = c(0.1, 0.3, 0.3, 0.4),
                                          fa_3 = c(0.9, 0.5, 0.4, NA),
                                          row.names = c("Prey_1", "Prey_2", "Prey_3",
-                                                       "Prey_4")),
+                                                       "Prey_4"),
+                                         stringsAsFactors = TRUE),
                      fa_names = c("fa_1", "fa_2", "fa_3"),
                      use_fa = c(TRUE, FALSE, TRUE),
                      zero_rep = 90,
